==> haskell-pid1-0.1.2.0-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pid1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pid1
version:              0.1.2.0
visibility:           public
id:                   pid1-0.1.2.0-FM0CMgScrwpKV98miNxv2K
key:                  pid1-0.1.2.0-FM0CMgScrwpKV98miNxv2K
license:              MIT
copyright:            2016 Michael Snoyman
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/pid1#readme
synopsis:
    Do signal handling and orphan reaping for Unix PID1 init processes

description:
    Please see README.md or view Haddocks at <https://www.stackage.org/package/pid1>

category:             System
abi:                  8a32f35ace778a8e35b6969cf7dfde1c
exposed:              True
exposed-modules:      System.Process.PID1
import-dirs:          /usr/lib/ghc-8.10.1/site-local/pid1-0.1.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/pid1-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/pid1-0.1.2.0
hs-libraries:         HSpid1-0.1.2.0-FM0CMgScrwpKV98miNxv2K
depends:
    base-4.14.0.0 directory-1.3.6.0 process-1.6.8.2 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pid1/html/pid1.haddock
haddock-html:         /usr/share/doc/haskell-pid1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pid1-0.1.2.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pid1.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pid1
version:              0.1.2.0
visibility:           public
id:                   pid1-0.1.2.0-GbSI9iJ0BU71HNgPX4Zl9u
key:                  pid1-0.1.2.0-GbSI9iJ0BU71HNgPX4Zl9u
license:              MIT
copyright:            2016 Michael Snoyman
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/pid1#readme
synopsis:
    Do signal handling and orphan reaping for Unix PID1 init processes

description:
    Please see README.md or view Haddocks at <https://www.stackage.org/package/pid1>

category:             System
abi:                  e0ebd4374df329ccc7bb63ee645f010e
exposed:              True
exposed-modules:      System.Process.PID1
import-dirs:          /usr/lib/ghc-8.10.2/site-local/pid1-0.1.2.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/pid1-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/pid1-0.1.2.0
hs-libraries:         HSpid1-0.1.2.0-GbSI9iJ0BU71HNgPX4Zl9u
depends:
    base-4.14.1.0 directory-1.3.6.0 process-1.6.9.0 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-pid1/html/pid1.haddock
haddock-html:         /usr/share/doc/haskell-pid1/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
